@@ -35,6 +35,9 @@ INTERNALERROR_ECDNDBERROR = 'InternalError.EcdnDbError'
 # 系统错误，请联系腾讯云工程师进一步排查。
 INTERNALERROR_ECDNSYSTEMERROR = 'InternalError.EcdnSystemError'
 
+# 内部服务错误，请联系腾讯云工程师进一步排查。
+INTERNALERROR_ERROR = 'InternalError.Error'
+
 # 后端服务错误,请稍后重试 。
 INTERNALERROR_PROXYSERVER = 'InternalError.ProxyServer'
 
@@ -200,6 +203,9 @@ UNAUTHORIZEDOPERATION_ECDNUSERNOWHITELIST = 'UnauthorizedOperation.EcdnUserNoWhi
 # ECDN 子账号cam未授权。
 UNAUTHORIZEDOPERATION_NOPERMISSION = 'UnauthorizedOperation.NoPermission'
 
+# 操作过于频繁，请稍后重试 。
+UNAUTHORIZEDOPERATION_OPERATIONTOOOFTEN = 'UnauthorizedOperation.OperationTooOften'
+
 # ECDN 子账号项目未授权。
 UNAUTHORIZEDOPERATION_PROJECTNOPERMISSION = 'UnauthorizedOperation.ProjectNoPermission'
 
